//
// Copyright (c) 2022, MindFusion LLC - Bulgaria.
//

using System;
using System.ComponentModel;
using System.Drawing;
using System.Windows.Forms;

using MindFusion.Diagramming;
using MindFusion.Diagramming.WinForms;
using MindFusion.Drawing;


namespace MindFusion.Diagramming.WinForms.Samples.CS.Anchors
{
	/// <summary>
	/// Summary description for MainForm.
	/// </summary>
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			var point = new AnchorPoint(15, 100, false, true);
			point.XUnit = UnitType.Fixed;
			point.YUnit = UnitType.Percentage;

			var pattern = new AnchorPattern(
				new AnchorPoint[] { point } );

			var container = diagram.Factory
				.CreateContainerNode(10, 10, 40, 60);
			container.AnchorPattern = pattern;

			diagram.Factory.CreateShapeNode(30, 120, 40, 40);
		}

		private void radioButton1_CheckedChanged(object sender, EventArgs e)
		{
			diagram.DefaultShape = Shapes.RoundRect;
		}

		private void radioButton2_CheckedChanged(object sender, EventArgs e)
		{
			diagram.DefaultShape = Shapes.Decision;
		}

		private void button1_Click(object sender, EventArgs e)
		{
			if (ofd.ShowDialog() == DialogResult.OK)
			{
				try
				{
					diagram.LoadFromFile(ofd.FileName);
				}
				catch (Exception ex)
				{
					MessageBox.Show(ex.Message);
				}
			}
		}

		private void button2_Click(object sender, EventArgs e)
		{
			if (sfd.ShowDialog() == DialogResult.OK)
			{
				diagram.SaveToFile(sfd.FileName, true);
			}
		}

		private void diagram_DrawAnchorPoint(object sender, DrawAnchorPointEventArgs e)
		{
			PointF imgPos = e.Location;
			imgPos.Y -= 1.8f;
			e.Graphics.DrawImage(icon.Image, imgPos);
		}

		private void diagram_NodeCreated(object sender, NodeEventArgs e)
		{
			ShapeNode node = e.Node as ShapeNode;
			if (node == null)
				return;

			if (node.Shape == Shapes.Decision)
				node.AnchorPattern = AnchorPattern.Decision1In3Out;
			else
				node.AnchorPattern = apat2;
		}


		private AnchorPattern apat1, apat2;
	}
}